/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.gui;

import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

import javafx.scene.control.ListCell;
import javafx.scene.image.Image;
import javafx.scene.image.ImageView;

public class LanguageSelectorCell extends ListCell<Locale> {
	
	private static Map<String, Image> imageCache = new HashMap<>();
	
	@Override
	protected void updateItem(Locale item, boolean empty) {
		super.updateItem(item, empty);
		if (item == null || empty) {
			setGraphic(null);
		} else {
			String country = item.getLanguage().toLowerCase(Locale.US);
			Image iconRef = imageCache.computeIfAbsent(country, key -> {
				String iconPath = "icons/icon_" + country + ".png";
				return new Image(MainWindow.class.getResourceAsStream(iconPath));
			});
			ImageView iconImageView = new ImageView(iconRef);
			setGraphic(iconImageView);
		}
	}

}
